# Universidade Estadual de Santa Cruz (UESC)
# Departamento de Cincias Agrrias e Ambientais (DCAA)
# Discentes: Rassa Alves, Jnatas Menezes, Vincius Magalhes, Adriano Barbosa, Amanda Pvoas
# Disciplina: CET 076 - Estatstica Experimental
# Docente: Jos Cludio Faria
# Revisado: 07/11/2022 17:10:51 J.C.Faria

# Exemplo apresentado no seminrio: Experimento dos diferentes tipos de bacilos na produo de Iogurte

#. Leitura dos dados
dir()  # Exibe contedo da pasta de trabalho (workdir)

dql <- read.table('dql.txt',
                  head=TRUE,
                  stringsAsFactors=TRUE)

str (dql)
head(dql)
tail (dql)

#... Verificando condies para anlise de varincia
attach(dql)
 is.factor(ln)
 is.factor(cl)
 is.factor(tra)
 is.numeric(pro)
detach(dql)

#. Mdias
#.. Linhas
with(dql,
     tapply(pro,
            ln,
            mean))

#.. Colunas
with(dql,
     tapply(pro,
            cl,
            mean))

#.. Tratamentos
with(dql,
     tapply(pro,
            tra,
            mean))


#. Elaborao de grficos (melhor visualizao)
#install.packages ('gplots')
library(gplots)

par(mfrow=c(3, 1))
# Linhas
plotmeans(pro ~ ln,
          main='Linhas',
          data=dql,
          mean.labels=TRUE,
          digits=2,
          connect=FALSE,
          ylab='Produo',
          pch=' ')

# Colunas
plotmeans(pro ~ cl,
          main='Colunas',
          data=dql,
          mean.labels=TRUE,
          digits=2,
          connect=FALSE,
          ylab='Produo',
          pch=' ')

# Tratamentos
plotmeans(pro ~ tra,
          main='Tratamentos',
          data=dql,
          col='red',
          mean.labels=TRUE,
          digits=2,
          connect=FALSE,
          ylab='Produo',
          pch=' ')


#. Anlise de varincia (ANOVA)
av <- aov(pro ~ ln + cl + tra,
          data=dql)
summary(av)

# Quantil da F: Fcal
(Ftab_ct <- qf(5/100,
               4,
               12,
               lower.tail=F))


#. Teste de comparao mdias mltiplas
#.. Tukey
library(TukeyC)

cv(av)  # cv: funo do pacote TukeyC

#... Linhas
tk_ln <- TukeyC(av,
                which='ln')
summary(tk_ln)

plot (tk_ln,
      disp='mm',
      ylab='Produo',
      xlab='Linhas',
      col='dark blue')

#... Colunas
tk_cl <- TukeyC(av,
                which='cl')
summary(tk_cl)

plot (tk_cl,
      disp='mm',
      ylab='Produo',
      xlab='Colunas',
      col='dark red')

#... Tratamentos
tk_tra <- TukeyC(av,
                 which='tra')
summary(tk_tra)

plot (tk_tra,
      disp='mm',
      ylab='Produo',
      xlab='Tratamentos',
      col='red')


#.. ScottKnott
library(ScottKnott)

#... Linhas
sk_ln <- SK(av,
            which='ln')

summary(sk_ln)

plot(sk_ln,
     disp= "mm",
     xlab='linhas',
     ylab='produo')

#... Colunas
sk_cl <- SK(av,
            which='cl')

summary(sk_cl)

plot(sk_cl,
     disp= "mm",
     xlab='colunas',
     ylab='produo')

#... Tratamentos
sk_tra <- SK(av,
            which='tra')

summary(sk_tra)

plot(sk_tra,
     disp= "mm",
     xlab='tratamentos',
     ylab='produo')


#. Contrastes ortogonais
                                           # t1  t2  t3  t4  t5
cmat <- rbind('(t2) vs (t1, t3, t4, t5)' = c(-1,  4, -1, -1, -1),
              '(t3, t4) vs (t1, t5)'     = c(-1,  0,  1,  1, -1),
              't3 vs t4'                 = c( 0,  0, -1,  1,  0),
              't1 vs t5'                 = c( 1,  0,  0,  0, -1))
cmat

library (gmodels) # necessitamos da funo: make.contrasts

av_c <- aov(pro ~ ln + cl + tra,
            data=dql,
            contrasts=list(tra=make.contrasts(cmat)))

# Verificao dos efeitos
effects(av_c)[10:13]
# ou
coef(av_c)[10:13]

summary(av_c,
        split=list(tra=list('(t2) vs (t1, t3, t4, t5)' = 1,
                            '(t3, t4) vs (t1, t5)'     = 2,
                            't3 vs t4'                 = 3,
                            't1 vs t5'                 = 4)))

# Quantil da F: Fcal
(Ftab_ct <- qf(5/100,
               1,
               12,
               lower.tail=F))
